@@ -1,5 +1,5 @@
 # Automated Enrollment manager
-# $Id: Enrollment.pm,v 1.34 2007/05/11 01:48:23 raeburn Exp $
+# $Id: Enrollment.pm,v 1.36 2007/08/03 22:02:01 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -454,7 +454,8 @@ sub update_LC {
 }
 
 sub create_newuser {
-    my ($args,$logmsg,$newusermsg,$enrollcount,$addresult,$longroles,$courseinfo) = @_;
+    my ($args,$logmsg,$newusermsg,$enrollcount,$addresult,$longroles,
+	$courseinfo,$called_context) = @_;
     my $auth = $args->{'auth'};
     my $authparam = $args->{'authparam'};
     my $emailenc = $args->{'emailenc'};
@@ -511,7 +512,7 @@ sub create_newuser {
         if ($context eq 'createowner' || $context eq 'createcourse') {
             my $result = &Apache::lonnet::modifyuser($udom,$uname,$pid,$auth,$authparam,$first,$middle,$last,$gene,'1',undef,$emailaddr);
             if ($result eq 'ok' && $context eq 'createcourse') {
-                $outcome = &Apache::loncommon::commit_standardrole($udom,$uname,$userurl,$role,$start,$end,$cdom,$crs,$usec);
+                $outcome = &Apache::loncommon::commit_standardrole($udom,$uname,$userurl,$role,$start,$end,$cdom,$crs,$usec,$called_context);
                 unless ($outcome =~ /^Error:/) {
                     $outcome = 'ok';
                 }
@@ -531,7 +532,7 @@ sub create_newuser {
             unless ($context eq 'createowner' || $context eq 'createcourse') {
                 $$enrollcount ++;
             }
-            if ($context eq 'automated') {
+            if ($called_context eq 'automated') {
                 $$logmsg .= &mt('New [_1] user [_2] added successfully.',$udom,$uname);
             }
             unless ($emailenc eq '' || $context eq 'createowner' || $context eq 'createcourse') {
@@ -563,11 +564,11 @@ sub create_newuser {
                     }
                     &Apache::lonmsg::sendemail($emailaddr,$subject,$body);
                 }
-                if ($context eq 'automated') {
+                if ($called_context eq 'automated') {
                     $$logmsg .= &mt(' Initial password - sent to ').$emailaddr.$linefeed;
                 }
             } else {
-                if ($context eq 'automated') {
+                if ($called_context eq 'automated') {
                     $$logmsg .= $linefeed;
                 }
             }
