@@ -1,7 +1,7 @@
 # LearningOnline Network with CAPA
 # option list style responses
 #
-# $Id: optionresponse.pm,v 1.143 2007/04/17 23:25:09 albertel Exp $
+# $Id: optionresponse.pm,v 1.144 2007/06/26 20:51:53 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -705,25 +705,29 @@ sub end_foil {
 
 sub start_drawoptionlist {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
-    if (($target ne 'meta')  && ($target ne 'answer')) {
+    if ($target !~ /^(?:meta|answer|modified|edit)$/) {
 	return $token->[4];
     }
 }
 
 sub end_drawoptionlist {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
-    if (($target ne 'meta') && ($target ne 'answer')) {
+    if ($target !~ /^(?:meta|answer|modified|edit)$/) {
 	return $token->[2];
     }
 }
 
 sub insert_foil {
-  return '
+    return '
 <foil name="" value="unused">
 <startouttext />
 <endouttext />
 </foil>';
 }
+
+sub insert_drawoptionlist {
+    return '<drawoptionlist />';
+}
 1;
 __END__
  
