@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # rank style response
 #
-# $Id: rankresponse.pm,v 1.49 2005/12/06 10:13:46 albertel Exp $
+# $Id: rankresponse.pm,v 1.52 2007/04/17 23:25:09 albertel Exp $
 # Copyright Michigan State University Board of Trustees
 #
 # This file is part of the LearningOnline Network with CAPA (LON-CAPA).
@@ -105,6 +105,7 @@ sub end_foilgroup {
 	if (!defined($tol)) { $tol=0; }
 	if ($target eq 'web' || $target eq 'tex') {
 	    $result=&displayfoils($target,$max,$randomize,$tol);
+	    $Apache::lonxml::post_evaluate=0;
 	} elsif ($target eq 'answer' ) {
 	    $result=&displayanswers($max,$randomize,$tol);
 	} elsif ( $target eq 'grade') {
@@ -263,6 +264,22 @@ sub grade_response {
     &Apache::response::handle_previous(\%previous,$ad);
 }
 
+sub format_prior_answer {
+    my ($mode,$answer,$other_data) = @_;
+    my %lastresponse=&Apache::lonnet::str2hash($answer);
+    my $foil_order  =$other_data->[0];
+    my %grading     =&Apache::lonnet::str2hash($other_data->[1]);
+    my $output;
+    foreach my $name (@{ $foil_order }) {
+	next if (!defined($lastresponse{$name}));
+	$output .= '<tr><td>'.$lastresponse{$name}.'</td></tr>';
+    }
+    return if (!defined($output));
+    $output =
+	'<table class="LC_prior_rank">'.$output.'</table>';
+    return $output;
+}
+
 sub displayfoils {
     my ($target,$max,$randomize,$tol)=@_;
     my $result;
@@ -304,7 +321,8 @@ sub displayfoils {
 		}
 	    }
 	    if ($target ne 'tex' && $Apache::lonhomework::type ne 'exam') {
-		$optionlist='<select name="HWVAL_'.
+		$optionlist='<select onchange="javascript:setSubmittedPart(\''.
+		  $part.'\');" name="HWVAL_'.
 		    $Apache::inputtags::response[-1].':'.$temp.'">'.
 		        $optionlist."</select>\n";
 	    } else {
@@ -333,6 +351,11 @@ sub displayfoils {
 	    $temp++;
 	}
     }
+    if ($target eq 'web') {
+	&Apache::response::setup_prior_tries_hash(\&format_prior_answer,
+						  [\@whichfoils,
+						   'submissiongrading']);
+    }
     if ($target ne 'tex') {$result.="<br />";} else {$result.=' \vskip 0 mm ';}
     return $result;
 }
