@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # various response type definitons response definition
 #
-# $Id: response.pm,v 1.167 2007/05/23 22:36:21 albertel Exp $
+# $Id: response.pm,v 1.173 2007/06/26 01:40:47 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -841,15 +841,46 @@ sub showallfoils {
     return 0;
 }
 
+=pod
+
+=item &getresponse($offset,$resulttype);
+
+Retreives the current submitted response, helps out in the case of
+scantron mode.
+
+Returns either the exact text of the submission, or a bubbled response
+converted to something usable.
+
+Optional Arguments:
+  $offset - (defaults to 1) if a problem has more than one bubble
+            response, pass in the number of the bubble wanted, (the
+            first bubble associated with a problem has an offset of 1,
+            the second bubble is 2
+
+  $resulttype - undef    -> a number between 0 and 25
+                'A is 1' -> a number between 1 and 26
+                'letter' -> a letter between 'A' and 'Z'
+  $lines  - undef problem only needs a single line of bubbles.
+            nonzero  Problem wants the first nonempty response in 
+                      $lines lines of bubbles.
+  $bubbles_per_line - Must be provided if lines is defined.. number of
+                      bubbles on a line.
+
+=cut
+
 sub getresponse {
-    my ($temp,$resulttype)=@_;
+    my ($offset,$resulttype, $lines, $bubbles_per_line)=@_;
     my $formparm='form.HWVAL_'.$Apache::inputtags::response['-1'];
     my $response;
-    if (!defined($temp)) {
-	$temp=1;
+    if (!defined($offset)) {
+	$offset=1;
     } else {
-	$formparm.=":$temp";
+	$formparm.=":$offset";
     }
+    if (!defined($lines)) {
+	$lines = 1;
+    }
+
     my %let_to_num=('A'=>0,'B'=>1,'C'=>2,'D'=>3,'E'=>4,'F'=>5,'G'=>6,'H'=>7,
 		    'I'=>8,'J'=>9,'K'=>10,'L'=>11,'M'=>12,'N'=>13,'O'=>14,
 		    'P'=>15,'Q'=>16,'R'=>17,'S'=>18,'T'=>19,'U'=>20,'V'=>21,
@@ -857,24 +888,55 @@ sub getresponse {
     if ($env{'form.submitted'} eq 'scantron') {
 	my $part  = $Apache::inputtags::part;
 	my $id    = $Apache::inputtags::response[-1];
-	$response = $env{'scantron.'.($Apache::lonxml::counter+$temp-1).
-			 '.answer'};
-	# save bubbled letter for later
-	$Apache::lonhomework::results{"resource.$part.$id.scantron"}.=
-	    $response;
+	
+	my $line;
+	for ($line = 0; $line < $lines; $line++) {
+	    $response = $env{'scantron.'.
+				 ($Apache::lonxml::counter+$offset-1+$line).
+				 '.answer'};
+	    if ($response ne "") {
+		last;
+	    }
+	    
+	}
 	if ($resulttype ne 'letter') {
 	    if ($resulttype eq 'A is 1') {
 		$response = $let_to_num{$response}+1;
 	    } else {
 		$response = $let_to_num{$response};
 	    }
+	    if ($response ne "") {
+		$response += $line * $bubbles_per_line;
+	    }
+	} else {
+	    if ($response ne "") {
+		$response = chr(ord($response) + $line * $bubbles_per_line);
+	    }
 	}
+	# save submitted response for later
+	$Apache::lonhomework::results{"resource.$part.$id.scantron"}.=
+	    $response;
+
     } else {
 	$response = $env{$formparm};
     }
+    # 
+    #  If we have a nonempty answer, correct the numeric value
+    #  of the answer for the line on which it was found.
+    #
+
     return $response;
 }
 
+=pod
+
+=item &repetition();
+
+Returns the number of lines that are required to encode the weight.
+(Currently expects that there are 10 bubbles per line)
+
+=cut
+
 sub repetition {
     my $id = $Apache::inputtags::part;
     my $weight = &Apache::lonnet::EXT("resource.$id.weight");
@@ -884,6 +946,30 @@ sub repetition {
     return $repetition;
 }
 
+=pod
+
+=item &scored_response($part_id,$response_id);
+
+Sets the results hash elements
+
+   resource.$part_id.$response_id.awarded - to the floating point
+     number between 0 and 1 that was awarded on the bubbled input
+
+   resource.$part_id.$response_id.awarddetail - to 'ASSIGNED_SCORE'
+
+Returns
+
+   the number of bubble sheet lines that were used (and likely need to
+     be passed to &Apache::lonxml::increment_counter()
+
+Arguments
+
+   $part_id - id of the part to grade
+   $response_id - id of the response to grade
+  
+
+=cut
+
 sub scored_response {
     my ($part,$id)=@_;
     my $repetition=&repetition();
