@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.382 2007/06/22 20:42:20 albertel Exp $
+# $Id: structuretags.pm,v 1.385 2007/07/24 18:03:54 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -47,9 +47,19 @@ BEGIN {
 
 sub start_web {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
-    my $bodytext=&Apache::lonxml::get_all_text("/web",$parser,$style);
-    if ($target eq 'web' || $target eq 'webgrade') {
-	return $bodytext;
+    if ($target ne 'edit' && $target ne 'modified') {
+	my $bodytext=&Apache::lonxml::get_all_text("/web",$parser,$style);
+	if ($target eq 'web' || $target eq 'webgrade') {
+	    return $bodytext;
+	}
+    } elsif ($target eq "edit" ) {
+	my $bodytext = 
+	    &Apache::lonxml::get_all_text_unbalanced("/web",$parser);
+	my $result = &Apache::edit::tag_start($target,$token);
+	$result .= &Apache::edit::editfield($token->[1],$bodytext,'',80,1);
+	return $result;
+    } elsif ( $target eq "modified" ) {
+	return $token->[4].&Apache::edit::modifiedfield("/web",$parser);
     }
     return '';
 }
@@ -61,9 +71,19 @@ sub end_web {
 sub start_tex {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     my $result='';
-    my $bodytext=&Apache::lonxml::get_all_text("/tex",$parser,$style);
-    if ($target eq 'tex') {
-	return $bodytext.' ';
+    if ($target ne 'edit' && $target ne 'modified') {
+	my $bodytext=&Apache::lonxml::get_all_text("/tex",$parser,$style);
+	if ($target eq 'tex') {
+	    return $bodytext.' ';
+	}
+    } elsif ($target eq "edit" ) {
+	my $bodytext = 
+	    &Apache::lonxml::get_all_text_unbalanced("/tex",$parser);
+	my $result = &Apache::edit::tag_start($target,$token);
+	$result .= &Apache::edit::editfield($token->[1],$bodytext,'',80,1);
+	return $result;
+    } elsif ( $target eq "modified" ) {
+	return $token->[4].&Apache::edit::modifiedfield("/tex",$parser);
     }
     return $result;;
 }
@@ -105,7 +125,7 @@ function setSubmittedPart (part) {
 
 	$extra_head .= &Apache::londefdef::generate_css_links();
 
-	if ($target eq 'edit') {
+	if ($env{'request.state'} eq 'construct') {
 	    $extra_head.=&Apache::edit::js_change_detection().
 		"<script type=\"text/javascript\">\n".
 		"if (typeof swmenu != 'undefined') {swmenu.currentURL=null;}\n".
@@ -289,16 +309,22 @@ sub problem_web_to_edit_header {
               <input type="text" name="rndseed" size="10" value="'.
 	       $rndseed.'"
            onchange="javascript:document.lonhomework.changerandseed.click()" /></nobr>
-             <label><input type="checkbox" name="showallfoils" ';
+             <span class="LC_nobreak"><label><input type="checkbox" name="showallfoils" ';
     my $show_all_foils_text = 
 	($Apache::lonhomework::parsing_a_task) ?
 	&mt('&nbsp;Show&nbsp;All&nbsp;Instances')
 	: &mt('&nbsp;Show&nbsp;All&nbsp;Foils');
 
     if (defined($env{'form.showallfoils'})) { $result.='checked="on"'; }
-    $result.= ' />'.$show_all_foils_text.'</label>'.
+    $result.= ' />'.$show_all_foils_text.'</label></span>'.
 	&Apache::loncommon::help_open_topic('Problem_Editor_Testing_Area','Testing Problems').
 	'<hr />';
+    $result.=&mt('Apply style file').'
+<input type="text" name="style_file" value="'.&HTML::Entities::encode($env{'construct.style'},'"<>&').'" />
+ <a href="javascript:openbrowser(\'lonhomework\',\'style_file\',\'sty\')">'.&mt('Select').'</a>
+<input type="submit" name="clear_style_file" value="'.&mt('Clear').'" />
+<br />';
+
     if (!$Apache::lonhomework::parsing_a_task) {
 	$result.="
 <nobr>
@@ -1055,7 +1081,7 @@ sub start_block {
     if ($target eq 'web' || $target eq 'grade'   || $target eq 'answer'  ||
 	$target eq 'tex' || $target eq 'analyze' || $target eq 'webgrade') {
 	my $code = $token->[2]->{'condition'};
-	if (defined($code)) {
+	if (defined($code) && $code ne '') {
 	    if (!$Apache::lonxml::default_homework_loaded) {
 		&Apache::lonxml::default_homework_load($safeeval);
 	    }
