@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: imsimportdocs.pm,v 1.19 2006/11/02 21:07:15 albertel Exp $
+# $Id: imsimportdocs.pm,v 1.20 2007/08/02 01:33:31 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -657,7 +657,7 @@ sub display_three {
         }
         my ($errtext,$fatal)=&Apache::londocs::group_import($crs,$cdom,$folder,'sequence','imsimport',@imports);
         if ($fatal) {
-            print STDERR "Fatal error during group_import\n";
+            &Apache::lonnet::logthis("Fatal error during group_import.");
         }
     }
     if ($tempdir =~ m/^\/home\/httpd\/perl\/tmp\/$crs\/\d{10}/) {
