@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Create a course
 #
-# $Id: loncreatecourse.pm,v 1.101.2.1 2007/06/01 18:07:47 albertel Exp $
+# $Id: loncreatecourse.pm,v 1.103.2.1 2007/08/02 19:52:30 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -576,7 +576,6 @@ sub create_course {
         $crstype='Course';
         $enrollstart=&Apache::lonhtmlcommon::get_date_from_form('startenroll');
         $enrollend=&Apache::lonhtmlcommon::get_date_from_form('endenroll');
-
     }
     $startaccess = &Apache::lonhtmlcommon::get_date_from_form('startaccess');
     $endaccess   = &Apache::lonhtmlcommon::get_date_from_form('endaccess');
@@ -677,7 +676,7 @@ sub create_course {
 # Make the requested user a course coordinator or group coordinator
 #
     if (($ccdomain) && ($ccuname)) {
-        $r->print(&mt('Assigning role of [_1] Coordinator to [_2] at [_3]:',
+        $r->print(&mt('Assigning role of [_1] Coordinator to [_2] at [_3]: ',
                      $crstype,$ccuname,$ccdomain).
                   &Apache::lonnet::assignrole($ccdomain,$ccuname,$courseid,
                                               'cc').'<p>');
@@ -795,7 +794,8 @@ sub process_batchfile {
             }
         }
     }
-    $r->print($start_page.$crumbs.$result.$end_page);
+    $r->print($start_page.$crumbs.$logmsg.$result.'<br /><a href="/adm/createcourse">'.
+              &mt('Creation options menu').'</a>'.$end_page);
  
 }
 
