@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.159 2007/05/13 18:03:15 banghart Exp $
+# $Id: lonhtmlcommon.pm,v 1.160 2007/07/11 20:32:15 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -140,6 +140,7 @@ sub select_recent {
     foreach my $value (sort(keys(%recent))) {
 	unless ($value =~/^error\:/) {
 	    my $escaped = &Apache::loncommon::escape_url($value);
+	    &Apache::loncommon::inhibit_menu_check(\$escaped);
 	    $return.="\n<option value='$escaped'>".
 		&unescape((split(/\&/,$recent{$value}))[1]).
 		'</option>';
@@ -1003,13 +1004,9 @@ sub crumbs {
 	    } else {
 		$path.='/'; 
 	    }	    
-            my $linkpath = &Apache::loncommon::escape_single($path);
-            if ($form) {
-		$linkpath=
-                    qq{javascript:$form.action='$linkpath';$form.submit();};
-            }
             my $href_path = &HTML::Entities::encode($path,'<>&"');
-	    $output.=qq{<a href="$path" $target>$dir</a>/};
+	    &Apache::loncommon::inhibit_menu_check(\$href_path);
+	    $output.=qq{<a href="$href_path" $target>$dir</a>/};
 	}
     } else {
 	foreach my $dir (split('/',$uri)) {
