@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Directory Indexer
 #
-# $Id: lonindexer.pm,v 1.158 2007/03/08 01:58:45 albertel Exp $
+# $Id: lonindexer.pm,v 1.173 2007/07/18 13:39:31 banghart Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -53,6 +53,7 @@ use Apache::lonmeta;
 use Apache::File;
 use Apache::lonlocal;
 use Apache::lonsource();
+use Apache::groupsort();
 use GDBM_File;
 use LONCAPA qw(:match);
 
@@ -128,7 +129,6 @@ sub handler {
 	    if ($env{'form.launch'} eq '1') {
 		&start_fresh_session(\%dbfile);
 	    }
-
 	    while(my($key,$value)=each(%dbfile)) {
 		$hash{$key}=$value;
 	    }
@@ -174,7 +174,7 @@ ENDSUBM
 	if ($env{'form.catalogmode'} eq 'interactive') {
 	    $extrafield='<td bgcolor="'.$fileclr.'" valign="bottom">'.
 		'<img alt="" src="'.$iconpath.'whitespace1.gif"'.
-		' border="0" /></td>';
+		' class="LC_icon" /></td>';
 	    $colspan=" colspan='2' ";
             my $cl=&mt('Close');
             $closebutton=<<END;
@@ -184,7 +184,7 @@ END
 	elsif ($env{'form.catalogmode'} eq 'import') {
 	    $extrafield='<td bgcolor="'.$fileclr.'" valign="bottom">'.
 		'<img alt="" src="'.$iconpath.'whitespace1.gif"'.
-		' border="0" /></td>';
+		' class="LC_icon" /></td>';
 	    $colspan=" colspan='2' ";
 	    my $cl=&mt('Close');
             my $gi=&mt('Import');
@@ -242,7 +242,7 @@ END
 #
 #
 	    if (!defined($mode) || ($mode ne 'edit' && $mode ne 'parmset')) {
-                my $location = "/adm/groupsort?catalogmode=import&";
+                my $location = "/adm/groupsort?&inhibitmenu=yes&catalogmode=import&";
                 $location .= "mode=".$mode."&";
                 $location .= "acts=";
 		$catalogmodefunctions=<<"END";
@@ -269,6 +269,9 @@ END
 function select_data(url) {
    var location = "/res/?launch=2&form=$form&element=$element&titleelement=$titleelement&acts=" + url;
    window.location=location;
+   if (window.opener.document.forms["$form"].elements["$element"].value != url) {
+       window.opener.unClean();
+   }
 }
 function select_group() {
     window.location="$location"+document.forms.fileattr.acts.value;
@@ -346,10 +349,38 @@ function queue(val) {
 END
 	}
 
+        my $inhibit_menu = "+'&".&Apache::loncommon::inhibit_menu_check()."'";
 # ---------------------------------------------------------------- Print Header
+        
 	my $js = <<"ENDHEADER";
 <script type="text/javascript">
 $catalogmodefunctions
+function checkAll() {
+    var numForms = document.forms.length;
+    for (i=0;i<numForms;i++) {
+        var numElements = document.forms[i].elements.length;
+        for (j=0;j<numElements;j++){
+            var fieldName = document.forms[i].elements[j].name;
+            if (fieldName == 'filelink') {
+                document.forms[i].elements[j].checked = true;
+                queue(document.forms[i].name);
+            }
+        }
+    }
+}
+function uncheckAll() {
+    var numForms = document.forms.length;
+    for (i=0;i<numForms;i++) {
+        var numElements = document.forms[i].elements.length;
+        for (j=0;j<numElements;j++){
+            var fieldName = document.forms[i].elements[j].name;
+            if (fieldName == 'filelink') {
+                document.forms[i].elements[j].checked = false;
+                queue(document.forms[i].name);
+            }
+        }
+    }
+}
 function openWindow(url, wdwName, w, h, toolbar,scrollbar,locationbar) {
     var xpos = (screen.width-w)/2;
     xpos = (xpos < 0) ? '0' : xpos;
@@ -362,7 +393,7 @@ function openWindow(url, wdwName, w, h, toolbar,scrollbar,locationbar) {
     newWin.focus();
 }
 function gothere(val) {
-    window.location=val+'?acts='+document.forms.fileattr.acts.value;
+    window.location=val+'?acts='+document.forms.fileattr.acts.value$inhibit_menu;
 }
 </script>
 ENDHEADER
@@ -372,44 +403,7 @@ ENDHEADER
 						 {'domain' => $headerdom,}));
 # - Evaluate actions from previous page (both cumulatively and chronologically)
         if ($env{'form.catalogmode'} eq 'import') {
-	    my $acts=$env{'form.acts'};
-	    my @Acts=split(/b/,$acts);
-	    my %ahash;
-	    my %achash;
-	    my $ac=0;
-	    # some initial hashes for working with data
-	    foreach (@Acts) {
-		my ($state,$ref)=split(/a/);
-		$ahash{$ref}=$state;
-		$achash{$ref}=$ac;
-		$ac++;
-	    }
-	    # sorting through the actions and changing the global database hash
-	    foreach (sort {$achash{$a}<=>$achash{$b}} (keys %ahash)) {
-		my $key=$_;
-		if ($ahash{$key} eq '1') {
-		    $hash{'store_'.$hash{'pre_'.$key.'_link'}}=
-			$hash{'pre_'.$key.'_title'};
-		    $hash{'storectr_'.$hash{'pre_'.$key.'_link'}}=
-			$hash{'storectr'}+0;
-		    $hash{'storectr'}++;
-		}
-		if ($ahash{$key} eq '0') {
-		    if ($hash{'store_'.$hash{'pre_'.$key.'_link'}}) {
-			delete $hash{'store_'.$hash{'pre_'.$key.'_link'}};
-		    }
-		}
-	    }
-	    # deleting the previously cached listing
-	    foreach (keys %hash) {
-		if ($_ =~ /^pre_/ && $_ =~/link$/) {
-		    my $key = $_;
-		    $key =~ s/^pre_//;
-		    $key =~ s/_[^_]*$//;
-		    delete $hash{'pre_'.$key.'_title'};
-		    delete $hash{'pre_'.$key.'_link'};
-		}
-	    }
+	    &Apache::groupsort::update_actions_hash(\%hash);
 	}
 	
 # ---------------------------------- get state of file attributes to be showing
@@ -474,6 +468,7 @@ ENDHEADER
 <input type="hidden" name="acts" value="" />
 $closebutton $groupimportbutton
 END
+        $r->print(&Apache::loncommon::inhibit_menu_check('input'));
 # -------------- Filter out sequence containment in crumbs and "recent folders"
 	my $storeuri=$uri;
 	$storeuri='/'.(split(/\.(page|sequence)\/\//,$uri))[-1];
@@ -489,7 +484,7 @@ END
 	if ($reshome) {
 	    $r->print("<font size='+2'><a href='");
 	    if ($env{'form.catalogmode'} eq 'import') {
-		$r->print('javascript:document.forms.fileattr.action="'.$reshome.'";document.forms.fileattr.submit();');
+		$r->print('javascript:document.forms.fileattr.action="'.&Apache::loncommon::inhibit_menu_check($reshome).'";document.forms.fileattr.submit();');
 	    } else {
 		$r->print($reshome);
 	    }
@@ -499,6 +494,11 @@ END
 # ------------------------------------------------------ Remember where we were
 	&Apache::loncommon::storeresurl($storeuri);
 	&Apache::lonhtmlcommon::store_recent('residx',$storeuri,$storeuri);
+# -------------------------------------------------- Check All and Uncheck all
+	if ($env{'form.catalogmode'} eq 'import') {
+	    $r->print('<br /><input type="button" value="'.&mt("Check All").'" id="checkallbutton" onClick="javascript:checkAll()" />');
+	    $r->print('<input type="button" value="'.&mt("Uncheck All").'" id="uncheckallbutton" onClick="javascript:uncheckAll()" />');
+	}
 # ----------------- output starting row to the indexed file/directory hierarchy
         my $titleclr="#ddffff";
         #$r->print(&initdebug());
@@ -812,7 +812,7 @@ sub display_line {
 	$updir='/'.(split(/\.(page|sequence)\/\//,$startdir))[-1];
 	$updir=~s/\/+/\//g;
 
-	$r->print("<tr valign='$valign' bgcolor=$fileclr>$extrafield");
+	$r->print("<tr valign='$valign' bgcolor=\"$fileclr\">$extrafield");
 	$r->print("<td>\n");
 	$r->print ('<form method="post" name="dirpathUP" action="'.$updir.
 		   '/" '.
@@ -820,11 +820,12 @@ sub display_line {
 		   'document.forms.fileattr.acts.value)" '.
 		   'enctype="application/x-www-form-urlencoded"'.
                    '>'."\n");
+	$r->print(&Apache::loncommon::inhibit_menu_check('input'));
 	$r->print ('<input type=hidden name=openuri value="'.
 		   $startdir.'" />'."\n");
 	$r->print ('<input type="hidden" name="acts" value="" />'."\n");
 	$r->print ('<input src="'.$iconpath.'arrow_up.gif"');
-	$r->print (' name="'.$msg.'" height="22" type="image" border="0" />'.
+	$r->print (' name="'.$msg.'" type="image" class="LC_indexer_icon" />'.
 		   "\n");
 	$r->print(&mt("Up")."</form>$tabtag</tr>\n");
 	return OK;
@@ -840,21 +841,21 @@ sub display_line {
     if ($filecom[1] eq 'domain') {
  	$r->print ('<input type="hidden" name="dirPointer" value="on" />'."\n")
  	    if ($env{'form.dirPointer'} eq "on");
-	$r->print("<tr valign='$valign' bgcolor=$fileclr>$extrafield");
+	$r->print("<tr valign='$valign' bgcolor=\"$fileclr\">$extrafield");
 	$r->print("<td>");
 	&begin_form ($r,$filecom[0]);
 	my $anchor = $filecom[0];
-	$anchor =~ s/\///g;
+	$anchor =~ s/\W//g;
 	$r->print ('<a name="'.$anchor.'"></a>');
 	$r->print ('<input type="hidden" name="acts" value="" />');
 	$r->print ('<input src="'.$iconpath.'folder_pointer_'.
 		   $diropen.'.gif"'); 
-	$r->print (' name="'.$msg.'" height="22" type="image" border="0" />'.
+	$r->print (' name="'.$msg.'" type="image" class="LC_indexer_icon" />'.
 		   "\n");
 	my $quotable_filecom = &Apache::loncommon::escape_single($filecom[0]);
 	$r->print ('<a href="javascript:gothere(\''.$quotable_filecom.
 		   '\')"><img alt="" src="'.$iconpath.'server.gif"');
-	$r->print (' border="0" /></a>'."\n");
+	$r->print (' class="LC_icon" /></a>'."\n");
 	$r->print (&mt("Domain")." - $listname ");
 	if (&Apache::lonnet::domain($listname,'description')) {
 	    $r->print("(".&Apache::lonnet::domain($listname,'description').
@@ -866,24 +867,23 @@ sub display_line {
 # display user directory
     }
     if ($filecom[1] eq 'user') {
-	$r->print("<tr valign=$valign bgcolor=$fileclr>$extrafield");
-	$r->print("<td nowrap>\n");
+	# $r->print("<tr valign=$valign bgcolor=\"$fileclr\">$extrafield");
 	my $curdir = $startdir.$filecom[0].'/';
 	my $anchor = $curdir;
-	$anchor =~ s/\///g;
+	$anchor =~ s/\W//g;
+	$r->print("<tr bgcolor=\"$fileclr\">$extrafield<td valign=$valign>");
 	&begin_form ($r,$curdir);
 	$r->print ('<a name="'.$anchor.'"></a><img alt="" src="'.$iconpath.
-		   'whitespace1.gif" border="0" />'."\n");
+		   'whitespace1.gif" class="LC_icon" />'."\n");
 	$r->print ('<input type="hidden" name="acts" value="" />');
 	$r->print ('<input src="'.$iconpath.'folder_pointer_'.$diropen.
 		   '.gif"'); 
-	$r->print (' name="'.$msg.'" height="22" type="image" border="0" />'.
+	$r->print (' name="'.$msg.'" type="image" class="LC_indexer_icon" />'.
 		   "\n");
 	my $quotable_curdir = &Apache::loncommon::escape_single($curdir);
 	$r->print ('<a href="javascript:gothere(\''.$quotable_curdir
-		   .'\')"><img alt="" src='.
-		   $iconpath.'quill.gif border="0" name="'.$msg.
-		   '" height="22" /></a>');
+		   .'\')"><img alt="'.$msg.'" src="'.
+		   $iconpath.'quill.gif" class="LC_indexer_icon" /></a>');
 	my $domain=(split(m|/|,$startdir))[2];
 	my $plainname=&Apache::loncommon::plainname($listname,$domain);
 	$r->print ($listname);
@@ -894,7 +894,11 @@ sub display_line {
 
 # display file
     if (($fnptr == 0 and $filecom[3] ne '') or $absolute) {
+        my $title;
 	my $filelink = $pathprefix.$filecom[0];
+	if ($hash{'display_attrs_0'} == 1) {
+	    $title = &Apache::lonnet::gettitle($filelink);
+	}
 	my @file_ext = split (/\./,$listname);
 	my $curfext = $file_ext[-1];
         if (@Omit) {
@@ -907,13 +911,13 @@ sub display_line {
         }
 	# Set the icon for the file
 	my $iconname = &Apache::loncommon::icon($listname);
-	$r->print("<tr valign='$valign' bgcolor=$fileclr><td nowrap='nowrap' valign='top'>");
+	$r->print("<tr valign='$valign' bgcolor=\"$fileclr\"><td nowrap='nowrap' valign='top'>");
 	
         if ($env{'form.catalogmode'} eq 'interactive') {
 	    my $quotable_filelink = &Apache::loncommon::escape_single($filelink);
             $r->print("<a href=\"javascript:select_data(\'",
                       $quotable_filelink,"')\">");
-	    $r->print("<img alt=\"\" src='",$iconpath,"select.gif' border='0' /></a>".
+	    $r->print("<img alt=\"\" src='",$iconpath,"select.gif' class='LC_icon' /></a>".
 		      "\n");
 	    $r->print("</td><td nowrap='nowrap' valign='top'>");
 	} elsif ($env{'form.catalogmode'} eq 'import') {
@@ -927,54 +931,56 @@ sub display_line {
 	    $r->print(" />\n");
 	    $r->print("</form></td><td nowrap='nowrap' valign='top'>");
 	    $hash{"pre_${fnum}_link"}=$filelink;
+	    $hash{"pre_${fnum}_title"}=$title;
+	    if (!$hash{"pre_${fnum}_title"}) {
+	        $hash{"pre_${fnum}_title"} = 'Not_retrieved';
+	    }
   	    $fnum++;
 	}
 # Form to open or close sequences
 	if ($filelink=~/\.(page|sequence)$/) {
 	    my $curdir = $startdir.$filecom[0].'/';
-	    my $anchor = $curdir;
-	    $anchor =~ s/\///g;
 	    &begin_form($r,$curdir);
 	    $indent--;
 	}
 # General indentation
 	if ($indent > 0 and $indent < 11) {
-	    $r->print("<img alt=\"\" src=",$iconpath,"whitespace",$indent,
-		      ".gif border='0' />\n");
+	    $r->print("<img alt=\"\" src='",$iconpath,"whitespace",$indent,
+		      ".gif' class='LC_icon' />\n");
 	} elsif ($indent >0) {
 	    my $ten = int($indent/10.);
 	    my $rem = $indent%10.0;
 	    my $count = 0;
 	    while ($count < $ten) {
-		$r->print("<img alt=\"\" src=",$iconpath,
-			  "whitespace10.gif border='0' />\n");
+		$r->print("<img alt=\"\" src=".$iconpath.
+			  "whitespace10.gif class='LC_icon' />\n");
 	    $count++;
 	    }
 	    $r->print("<img alt=\"\" src=",$iconpath,"whitespace",$rem,
-		      ".gif border='0' />\n") if $rem > 0;
+		      ".gif class='LC_icon' />\n") if $rem > 0;
 	}
 # Sequence open/close icon
 	if ($filelink=~/\.(page|sequence)$/) {
 	    my $curdir = $startdir.$filecom[0].'/';
 	    my $anchor = $curdir;
-	    $anchor =~ s/\///g;
+	    $anchor =~ s/\W//g;
 	    $r->print ('<input type="hidden" name="acts" value="" />');
 	    $r->print ('<a name="'.$anchor.'"></a><input src="'.$iconpath.
 		       'folder_pointer_'.$diropen.'.gif"');
-	    $r->print (' name="'.$msg.'" height="22" type="image" border="0" />'.
+	    $r->print (' name="'.$msg.'" type="image" class="LC_indexer_icon" />'.
 		       "\n");
 	}
 # Filetype icons
-	$r->print("<img alt=\"\" src='$iconname' border='0' />\n");
+	$r->print("<img alt=\"\" src='$iconname' class='LC_icon' />\n");
 	my $quotable_filelink = &Apache::loncommon::escape_single($filelink);
 
-
 	$r->print (" <a href=\"javascript:openWindow('".$quotable_filelink.
-		   "', 'previewfile', '450', '500', 'no', 'yes','yes');\"".
+		   "?inhibitmenu=yes','previewfile','450','500','no','yes','yes');\"".
 		   " target=\"_self\">$listname</a> ");
-
+	$quotable_filelink = &Apache::loncommon::escape_single($filelink.'.meta');
+	&Apache::loncommon::inhibit_menu_check(\$quotable_filelink);
 	$r->print (" (<a href=\"javascript:openWindow('".$quotable_filelink.
-		   ".meta', 'metadatafile', '500', '550', 'no', 'yes','no');\" ".
+		   "?inhibitmenu=yes','metadatafile','500','550','no','yes','no');\" ".
 		   " target=\"_self\">metadata</a>) ");
 # Close form to open/close sequence
 	if ($filelink=~/\.(page|sequence)$/) {
@@ -982,7 +988,6 @@ sub display_line {
 	}
 	$r->print("</td>\n");
 	if ($hash{'display_attrs_0'} == 1) {
-	    my $title = &Apache::lonnet::gettitle($filelink,'title');
 	    $r->print('<td> '.($title eq '' ? '&nbsp;' : $title).
 		      ' </td>'."\n");
 	}
@@ -1038,6 +1043,7 @@ sub display_line {
 	    if($source eq 'open') {
 		my $sourcelink = &Apache::lonsource::make_link($filelink,$listname);
 		my $quotable_sourcelink = &Apache::loncommon::escape_single($sourcelink);
+		&Apache::loncommon::inhibit_menu_check(\$quotable_sourcelink);
 		$r->print('<td>'."<a href=\"javascript:openWindow('"
 			  .$quotable_sourcelink.
 			  "', 'previewsource', '700', '700', 'no', 'yes','yes');\"".
@@ -1071,42 +1077,42 @@ sub display_line {
     if ($fnptr == $dirptr) {
 	my $curdir = $startdir.$filecom[0].'/';
 	my $anchor = $curdir;
-	$anchor =~ s/\///g;
-	$r->print("<tr bgcolor=$fileclr>$extrafield<td valign=$valign>");
+	$anchor =~ s/\W//g;
+	$r->print("<tr bgcolor=\"$fileclr\">$extrafield<td valign=$valign>");
 	&begin_form ($r,$curdir);
 	my $indentm1 = $indent-1;
 	if ($indentm1 < 11 and $indentm1 > 0) {
 	    $r->print("<img alt=\"\" src=",$iconpath,"whitespace",$indentm1,
-		      ".gif border='0' />\n");
+		      ".gif class='LC_icon' />\n");
 	} else {
 	    my $ten = int($indentm1/10.);
 	    my $rem = $indentm1%10.0;
 	    my $count = 0;
 	    while ($count < $ten) {
 		$r->print ("<img alt=\"\" src=",$iconpath
-			   ,"whitespace10.gif border='0' />\n");
+			   ,"whitespace10.gif class='LC_icon' />\n");
 		$count++;
 	    }
 	    $r->print ("<img alt=\"\" src=",$iconpath,"whitespace",$rem,
-		       ".gif border='0' />\n") if $rem > 0;
+		       ".gif class='LC_icon' />\n") if $rem > 0;
 	}
 	$r->print ('<input type="hidden" name="acts" value="" />');
 	$r->print ('<a name="'.$anchor.'"></a><input src="'.$iconpath.
 		   'folder_pointer_'.$diropen.'.gif"');
-	$r->print (' name="'.$msg.'" height="22" type="image" border="0" />'.
+	$r->print (' name="'.$msg.'" type="image" class="LC_indexer_icon" />'.
 		   "\n");
 	my $quotable_curdir = &Apache::loncommon::escape_single($curdir);
 	$r->print ('<a href="javascript:gothere(\''
 		   .$quotable_curdir.'\')">'
 		   .'<img alt="'.&mt('Open Folder').'"src="'.
-		   $iconpath.'folder_'.$diropen.'.gif" border="0" /></a>'.
+		   $iconpath.'folder_'.$diropen.'.gif" class="LC_icon" /></a>'.
 		   "\n");
 	$r->print ("$listname</form></td>\n");
 # Attributes
 	my $filelink = $startdir.$filecom[0].'/default';
 
 	if ($hash{'display_attrs_0'} == 1) {
-	    my $title = &Apache::lonnet::gettitle($filelink,'title');
+	    my $title = &Apache::lonnet::gettitle($filelink);
 	    $r->print('<td> '.($title eq '' ? '&nbsp;' : $title).
 		      ' </td>'."\n");
 	}
@@ -1225,7 +1231,8 @@ sub dynmetaprint {
 sub begin_form {
     my ($r,$uri) = @_;
     my $anchor = $uri;
-    $anchor =~ s/\///g;
+    $anchor =~ s/\W//g;
+    $uri=&Apache::loncommon::escape_single($uri);
     $r->print ('<form method="post" name="dirpath'.$dnum.'" action="'.$uri.
 	       '#'.$anchor.
 	       '" onSubmit="return rep_dirpath(\''.$dnum.'\''.
@@ -1234,6 +1241,7 @@ sub begin_form {
     $r->print ('<input type="hidden" name="openuri" value="'.$uri.'" />'.
 	       "\n");
     $r->print ('<input type="hidden" name="dirPointer" value="on" />'."\n");
+    $r->print(&Apache::loncommon::inhibit_menu_check('input'));
     $dnum++;
 }
 
