@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Pick a student from the classlist
 #
-# $Id: lonpickstudent.pm,v 1.20 2006/12/06 20:54:13 albertel Exp $
+# $Id: lonpickstudent.pm,v 1.22 2007/08/02 01:39:26 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -70,10 +70,23 @@ sub handler {
 # See if filter present
     my $filter=$env{'form.filter'};
     my $filtermsg;
-    if ($filter ne '') {
-	$filtermsg = '<br />'.&mt('Name starting with').' "'.$filter.'"<br />';
-	$filter = quotemeta($filter);
-    } else {
+    my $encoded_filter = &HTML::Entities::encode($filter,'<>&"');
+    $filter = quotemeta($filter);
+    my $change = &mt('Change');
+    my $filterbutton =<<FILTER;
+  <input type="text" name="filter" value="$encoded_filter" />
+  <input type="submit" name="Change" value="$change" />
+FILTER
+    foreach my $name ('form','unameelement','udomelement','roles') {
+	my $value = &HTML::Entities::encode($env{"form.$name"},'<>&"');
+	$filterbutton .= <<HIDDEN;
+   <input type="hidden" name="$name" value="$value" />
+HIDDEN
+    }
+    $filtermsg = '<br />'.
+	&mt('Showing users with a name starting with [_1]',
+	    $filterbutton).'<br />';
+    if ($filter eq '') {
 	$filter = '.'
     }
 
@@ -125,19 +138,10 @@ ENDSCRIPT
 
 	$r->print($filtermsg);
 
-	$r->print('</p><p>'.
-		  &Apache::loncommon::start_data_table().
-		  &Apache::loncommon::start_data_table_header_row().
-		  &Apache::loncommon::end_data_table_header_row().
-		  '<th>&nbsp;</th>'.
-		  '<th>'.&mt('username').'</th>'.
-		  '<th>'.&mt('domain').'</th>'.
-		  '<th>'.&mt('Name').'</th>'.
-		  '<th>'.&mt('ID').'</th>'.
-		  '<th>'.&mt('section').'</th>'.
-		  '<th>'.&mt('active group(s)').'</th>'.
-		  &Apache::loncommon::end_data_table_header_row());
+	$r->print('</p>');
+
 # ------------------------------------------------------------------ Students
+	my $result;
 	foreach my $user (sort(keys(%$classlist))) {
 	    # the following undefs are for 'domain', and 'username' respectively.
 	    my (undef,undef,$end,$start,$id,$section,$fullname,$status)=
@@ -159,7 +163,7 @@ ENDSCRIPT
 			}
 		    }
 		    $grouplist =~ s/,$//;
-		    $r->print(&Apache::loncommon::start_data_table_row().
+		    $result .=&Apache::loncommon::start_data_table_row().
 			      '<td>'.
 			      '<input type="button" value="'.&mt('Select').'" onClick="gochoose('.
 			      "'".$uname."','".$udom."')".'" /></td>'.
@@ -169,12 +173,27 @@ ENDSCRIPT
 								 $uname,$udom).
 			      '</td><td>'.$id.'</td><td>'.$section.
 			      '</td><td>'.$grouplist.'</td>'.
-			      &Apache::loncommon::end_data_table_row());
+			      &Apache::loncommon::end_data_table_row();
 		}
 	    }
 	}
-	
-	$r->print(&Apache::loncommon::end_data_table().'</p>');
+	if (!$result) {
+	    $r->print('<p>'.&mt('No students found.').'</p>');
+	} else {
+	    $r->print(&Apache::loncommon::start_data_table().
+		      &Apache::loncommon::start_data_table_header_row().
+		      &Apache::loncommon::end_data_table_header_row().
+		      '<th>&nbsp;</th>'.
+		      '<th>'.&mt('username').'</th>'.
+		      '<th>'.&mt('domain').'</th>'.
+		      '<th>'.&mt('Name').'</th>'.
+		      '<th>'.&mt('ID').'</th>'.
+		      '<th>'.&mt('section').'</th>'.
+		      '<th>'.&mt('active group(s)').'</th>'.
+		      &Apache::loncommon::end_data_table_header_row().
+		      $result.
+		      &Apache::loncommon::end_data_table());
+	}
     } else {
 	$r->print('<h3>'.&mt('Users with Roles Assigned by').' '.
 		  &Apache::loncommon::plainname($env{'user.name'},
