@@ -1,5 +1,5 @@
 #
-# $Id: lonwhatsnew.pm,v 1.71 2007/05/02 01:33:49 albertel Exp $
+# $Id: lonwhatsnew.pm,v 1.72 2007/06/06 17:35:32 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1332,7 +1332,7 @@ sub display_coursenormalmail {
             $r->print('<tr'.$css_class.'><td>'.$mailcount.
                       '. &nbsp;</td><td><a href="/adm/communicate">'.
                       $msg->{'shortsub'}.'</a>&nbsp; &nbsp;</td><td>&nbsp;'.
-                      $msg->{'from'}.'@'.$msg->{'fromdom'}.'&nbsp;</td><td>'.
+                      $msg->{'from'}.':'.$msg->{'fromdom'}.'&nbsp;</td><td>'.
                       $msg->{'sendtime'}.'</td></tr>');
         }
     } else {
@@ -1356,7 +1356,7 @@ sub display_coursecritmail {
             $r->print('<tr'.$css_class.'><td>'.$mailcount.
                       '. &nbsp;</td><td><a href="/adm/email?folder=critical">'.
                       $msg->{'shortsub'}.'</a>&nbsp; &nbsp;</td><td>&nbsp;'.
-                      $msg->{'from'}.'@'.$msg->{'fromdom'}.'&nbsp;</td><td>'.
+                      $msg->{'from'}.':'.$msg->{'fromdom'}.'&nbsp;</td><td>'.
                       $msg->{'sendtime'}.'</td></tr>');
         }
     } else {
