@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler for requesting to have slots added to a students record
 #
-# $Id: slotrequest.pm,v 1.73 2006/12/18 22:59:30 albertel Exp $
+# $Id: slotrequest.pm,v 1.79 2007/04/11 21:49:02 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -334,7 +334,7 @@ sub remove_registration {
     my %consumed=&Apache::lonnet::dump('slot_reservations',$cdom,$cnum,
 				       "^$slot_name\0");
     if (&Apache::lonnet::error(%consumed)) {
-	$r->print("<p>".&mt('A network error has occured.').'</p>');
+	$r->print("<p><span class=\"LC_error\">".&mt('A network error has occured.').'</span></p>');
 	return;
     }
     if (!%consumed) {
@@ -527,7 +527,7 @@ sub delete_slot {
 	if ($ret eq 'ok') {
 	    $r->print("<p>Slot <tt>$slot_name</tt> marked as deleted.</p>");
 	} else {
-	    $r->print("<p> An error ($ret) occurse when attempting to delete Slot <tt>$slot_name</tt>.</p>");
+	    $r->print("<p><span class=\"LC_error\"> An error ($ret) occurse when attempting to delete Slot <tt>$slot_name</tt>.</span></p>");
 	}
     } else {
 	if (%consumed) {
@@ -548,17 +548,17 @@ sub return_link {
 }
 
 sub get_slot {
-    my ($r,$symb)=@_;
+    my ($r,$symb,$conflictable_slot,$inhibit_return_link)=@_;
 
     my %slot=&Apache::lonnet::get_slot($env{'form.slotname'});
     my $slot_name=&check_for_conflict($symb,$env{'form.slotname'},\%slot);
 
     if ($slot_name =~ /^error: (.*)/) {
-	$r->print("<p>An error occured while attempting to make a reservation. ($1)</p>");
+	$r->print("<p><span class=\"LC_error\">An error occured while attempting to make a reservation. ($1)</span></p>");
 	&return_link($r);
-	return;
+	return 0;
     }
-    if ($slot_name) {
+    if ($slot_name && $slot_name ne $conflictable_slot) {
 	my %slot=&Apache::lonnet::get_slot($slot_name);
 	my $description1=&get_description($slot_name,\%slot);
 	%slot=&Apache::lonnet::get_slot($env{'form.slotname'});
@@ -586,36 +586,44 @@ STUFF
         } else {
 	    &return_link($r);
 	}
-	return;
+	return 0;
     }
 
     my $reserved=&make_reservation($env{'form.slotname'},
 				   \%slot,$symb);
     my $description=&get_description($env{'form.slotname'},\%slot);
     if (defined($reserved)) {
+	my $retvalue = 0;
 	if ($slot_name =~ /^error: (.*)/) {
-	    $r->print("<p>An error occured while attempting to make a reservation. ($1)</p>");
+	    $r->print("<p><span class=\"LC_error\">An error occured while attempting to make a reservation. ($1)</span></p>");
 	} elsif ($reserved > -1) {
 	    $r->print("<p>Success: $description</p>");
+	    $retvalue = 1;
 	} elsif ($reserved < 0) {
 	    $r->print("<p>Already reserved: $description</p>");
 	}
-	&return_link($r);
-	return;
+	if (!$inhibit_return_link) { &return_link($r); }
+	return 1;
     }
 
     my %lt=('request'=>"Availibility list",
 	    'try'    =>'Try again');
     %lt=&Apache::lonlocal::texthash(%lt);
 
+    my $extra_input;
+    if ($conflictable_slot) {
+	$extra_input='<input type="hidden" name="releaseslot" value="'.$env{'form.slotname'}.'" />';
+    }
+
     $r->print(<<STUFF);
-<p> <font color="red">Failed</font> to reserve a spot for $description. </p>
+<p> <span class="LC_warning">Failed</span> to reserve a spot for $description. </p>
 <p>
 <form method="post" action="/adm/slotrequest">
    <input type="submit" name="Try Again" value="$lt{'try'}" />
    <input type="hidden" name="symb" value="$env{'form.symb'}" />
    <input type="hidden" name="slotname" value="$env{'form.slotname'}" />
-   <input type="hidden" name="command" value="get" />
+   <input type="hidden" name="command" value="$env{'form.command'}" />
+   $extra_input
 </form>
 ?
 </p>
@@ -629,8 +637,8 @@ or
 or
 STUFF
 
-    &return_link($r);
-    return;
+    if (!$inhibit_return_link) { &return_link($r); }
+    return 0;
 }
 
 sub allowed_slot {
@@ -638,8 +646,7 @@ sub allowed_slot {
 
     #already started
     if ($slot->{'starttime'} < time) {
-	# all open slot to be schedulable
-	#return 0;
+	return 0;
     }
     &Apache::lonxml::debug("$slot_name starttime good");
 
@@ -932,7 +939,7 @@ sub show_table {
 	     'endtime'         => 'End Time',
              'startreserve'    => 'Time students can start reserving',
 	     'secret'          => 'Secret Word',
-	     'maxspace'        => 'Maximum # of students',
+	     'space'           => '# of students/max',
 	     'ip'              => 'IP or DNS restrictions',
 	     'symb'            => 'Resource slot is restricted to.',
 	     'allowedsections' => 'Sections slot is restricted to.',
@@ -941,7 +948,7 @@ sub show_table {
 	     'scheduled'       => 'Scheduled Students',
 	     'proctor'         => 'List of proctors');
     my @show_order=('name','description','type','starttime','endtime',
-		    'startreserve','secret','maxspace','ip','symb',
+		    'startreserve','secret','space','ip','symb',
 		    'allowedsections','allowedusers','uniqueperiod',
 		    'scheduled','proctor');
     my @show = 
@@ -1053,12 +1060,16 @@ sub show_table {
 
     my %name_cache;
     my $slotsort = sub {
-	if ($env{'form.order'}=~/^(type|description|endtime|startreserve|maxspace|ip|symb|allowedsections|allowedusers)$/) {
+	if ($env{'form.order'}=~/^(type|description|endtime|startreserve|ip|symb|allowedsections|allowedusers)$/) {
 	    if (lc($slots{$a}->{$env{'form.order'}})
 		ne lc($slots{$b}->{$env{'form.order'}})) {
 		return (lc($slots{$a}->{$env{'form.order'}}) 
 			cmp lc($slots{$b}->{$env{'form.order'}}));
 	    }
+	} elsif ($env{'form.order'} eq 'space') {
+	    if ($slots{$a}{'maxspace'} ne $slots{$b}{'maxspace'}) {
+		return ($slots{$a}{'maxspace'} cmp $slots{$b}{'maxspace'});
+	    }
 	} elsif ($env{'form.order'} eq 'name') {
 	    if (lc($a) cmp lc($b)) {
 		return lc($a) cmp lc($b);
@@ -1078,6 +1089,14 @@ sub show_table {
 	}
 	return $slots{$a}->{'starttime'} <=> $slots{$b}->{'starttime'};
     };
+
+    my %consumed;
+    if (exists($show{'scheduled'}) || exists($show{'space'}) ) {
+	%consumed=&Apache::lonnet::dump('slot_reservations',$cdom,$cnum);
+	my ($tmp)=%consumed;
+	if ($tmp =~ /^error: /) { undef(%consumed); }
+    }
+
     foreach my $slot (sort $slotsort (keys(%slots)))  {
 	if (!&to_show($slot,$slots{$slot},$when,
 		      $env{'form.deleted'},$name_filter)) { next; }
@@ -1086,15 +1105,16 @@ sub show_table {
 	    #next;
 	}
 	my $description=&get_description($slot,$slots{$slot});
-	my $ids;
-	if (exists($show{'scheduled'})) {
-	    my %consumed=&Apache::lonnet::dump('slot_reservations',$cdom,$cnum,
-					       "^$slot\0");
-	    my ($tmp)=%consumed;
-	    if ($tmp !~ /^error: /) {
+	my ($id_count,$ids);
+	    
+	if (exists($show{'scheduled'}) || exists($show{'space'}) ) {
+	    my $re_str = "$slot\0";
+	    my @this_slot = grep(/^\Q$re_str\E/,keys(%consumed));
+	    $id_count = scalar(@this_slot);
+	    if (exists($show{'scheduled'})) {
 		foreach my $entry (sort { $consumed{$a}{name} cmp 
 					      $consumed{$b}{name} }
-				   (keys(%consumed))) {
+				   (@this_slot)) {
 		    my (undef,$id)=split("\0",$entry);
 		    my ($uname,$udom) = split(':',$consumed{$entry}{'name'});
 		    $ids.= '<nobr>';
@@ -1216,8 +1236,15 @@ DELETELINK
 	if (exists($show{'secret'})) {
 	    $colspan++;$r->print("<td>$slots{$slot}{'secret'}</td>\n");
 	}
-	if (exists($show{'maxspace'})) {
-	    $colspan++;$r->print("<td>$slots{$slot}{'maxspace'}</td>\n");
+	if (exists($show{'space'})) {
+	    my $display = $id_count;
+	    if ($slots{$slot}{'maxspace'}>0) {
+		$display.='/'.$slots{$slot}{'maxspace'};
+		if ($slots{$slot}{'maxspace'} <= $id_count) {
+		    $display = '<strong>'.$display.' (full) </strong>';
+		}
+	    }
+	    $colspan++;$r->print("<td>$display</td>\n");
 	}
 	if (exists($show{'ip'})) {
 	    $colspan++;$r->print("<td>$slots{$slot}{'ip'}</td>\n");
@@ -1521,7 +1548,7 @@ sub csv_upload_assign {
     }
     $r->print("<p>Created $countdone slots\n</p>");
     foreach my $error (@errors) {
-	$r->print("<p>$error\n</p>");
+	$r->print("<p><span class=\"LC_warning\">$error</span></p>\n");
     }
     &show_table($r,$mgr);
     return '';
@@ -1605,8 +1632,8 @@ sub handler {
 	} elsif ($env{'form.command'} eq 'get') {
 	    &get_slot($r,$symb);
 	} elsif ($env{'form.command'} eq 'change') {
-	    if (&release_slot($r,$symb,$env{'form.releaseslot'},1)) {
-		&get_slot($r,$symb);
+	    if (&get_slot($r,$symb,$env{'form.releaseslot'},1)) {
+		&release_slot($r,$symb,$env{'form.releaseslot'});
 	    }
 	} else {
 	    $r->print("<p>Unknown command: ".$env{'form.command'}."</p>");
