@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construction Space Directory Lister
 #
-# $Id: lonpubdir.pm,v 1.102 2007/04/20 01:17:24 albertel Exp $
+# $Id: lonpubdir.pm,v 1.103 2007/07/25 19:56:57 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -356,6 +356,7 @@ sub dircontrols {
                                        ncrf => 'New custom rights file',
                                        nsty => 'New style file',
                                        nlib => 'New library file',
+                                       nbt  => 'New bridgetask file',
                                        nsub => 'New subdirectory',
                                        renm => 'Rename current file to',
                                        move => 'Move current file to',
@@ -414,6 +415,7 @@ sub dircontrols {
                             <option value="newsequencefile">$lt{'nseq'}:</option>
                             <option value="newrightsfile">$lt{'ncrf'}:</option>
                             <option value="newstyfile">$lt{'nsty'}:</option>
+                            <option value="newtaskfile">$lt{'nbt'}:</option>
                             <option value="newlibraryfile">$lt{'nlib'}:</option>
 			    <option value="newdir">$lt{'nsub'}:</option>
 		  </select>&nbsp;<input type="text" name="newfilename" value="Type Name Here" onfocus="if (this.value == 'Type Name Here') this.value=''" />&nbsp;<input type="button" value="Go" onclick="document.fileaction.submit()" />
