@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # TeX Conversion Module
 #
-# $Id: lontexconvert.pm,v 1.82 2007/06/13 00:21:03 albertel Exp $
+# $Id: lontexconvert.pm,v 1.83 2007/06/19 20:10:55 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -205,11 +205,24 @@ sub jsMath_converted {
     }
 }
 
+sub tex_engine {
+    if (exists($env{'form.texengine'})) {
+	return $env{'form.texengine'};
+    }    
+    if ($env{'request.course.id'}
+	&& exists($env{'course.'.$env{'request.course.id'}.'.texengine'})) {
+	return $env{'course.'.$env{'request.course.id'}.'.texengine'};
+    }
+    if (exists($env{'environment.texengine'})) {
+	return $env{'environment.texengine'};
+    }
+    return 'tth';
+}
+
 sub init_math_support {
     &init_tth();
     &Apache::lontexconvert::jsMath_push();
-    if ($env{'environment.texengine'} eq 'jsMath' ||
-	$env{'form.texengine'}        eq 'jsMath' ) {
+    if (lc(&tex_engine()) eq 'jsmath') {
 	return &Apache::lontexconvert::jsMath_header();
     }
     return;
@@ -233,7 +246,7 @@ sub mimetex_converted {
 
 sub converted {
     my ($string,$mode)=@_;
-    if ($mode eq '') { $mode=$env{'environment.texengine'}; }
+    if ($mode eq '') { $mode = &tex_engine(); }
     if ($mode =~ /tth/i) {
 	return &tth_converted($string);
     } elsif ($mode =~ /jsmath/i) {
